==> haskell-ghc-typelits-knownnat-0.5.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-typelits-knownnat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-typelits-knownnat
version: 0.5.1
id: ghc-typelits-knownnat-0.5.1-9CO2uWi3AoKBWXvo0WCUXf
key: ghc-typelits-knownnat-0.5.1-9CO2uWi3AoKBWXvo0WCUXf
license: BSD-2-Clause
copyright: Copyright © 2016     , University of Twente,
           2017-2018, QBayLogic B.V.,
           2017     , Google Inc.
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://clash-lang.org/
synopsis: Derive KnownNat constraints from other KnownNat constraints
description:
    A type checker plugin for GHC that can derive \"complex\" @KnownNat@
    constraints from other simple/variable @KnownNat@ constraints. i.e. without
    this plugin, you must have both a @KnownNat n@ and a @KnownNat (n+2)@
    constraint in the type signature of the following function:
    .
    @
    f :: forall n . (KnownNat n, KnownNat (n+2)) => Proxy n -> Integer
    f _ = natVal (Proxy :: Proxy n) + natVal (Proxy :: Proxy (n+2))
    @
    .
    Using the plugin you can omit the @KnownNat (n+2)@ constraint:
    .
    @
    f :: forall n . KnownNat n => Proxy n -> Integer
    f _ = natVal (Proxy :: Proxy n) + natVal (Proxy :: Proxy (n+2))
    @
    .
    The plugin can derive @KnownNat@ constraints for types consisting of:
    .
    * Type variables, when there is a corresponding @KnownNat@ constraint
    .
    * Type-level naturals
    .
    * Applications of the arithmetic expression: +,-,*,^
    .
    * Type functions, when there is either:
    .
    1. a matching given @KnownNat@ constraint; or
    .
    2. a corresponding @KnownNat\<N\>@ instance for the type function
    .
    To use the plugin, add the
    .
    @
    OPTIONS_GHC -fplugin GHC.TypeLits.KnownNat.Solver
    @
    .
    Pragma to the header of your file.
category: Type System
abi: a070e094a843825c075220d926f04263
exposed: True
exposed-modules:
    GHC.TypeLits.KnownNat GHC.TypeLits.KnownNat.Solver
hidden-modules: GHC.TypeLits.KnownNat.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/ghc-typelits-knownnat-0.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/ghc-typelits-knownnat-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ghc-typelits-knownnat-0.5.1
hs-libraries: HSghc-typelits-knownnat-0.5.1-9CO2uWi3AoKBWXvo0WCUXf
depends:
    base-4.11.1.0 ghc-8.4.3
    ghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB
    ghc-typelits-natnormalise-0.6.2-Hdc4FExbZN2FNN2aRJtwTz
    transformers-0.5.5.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-8.4.3=b85a78185b88bdae88410d8ef8f69684
             ghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB=ce7823a6fd180b4f7432a3604d6a13e8
             ghc-typelits-natnormalise-0.6.2-Hdc4FExbZN2FNN2aRJtwTz=8287e131359cea3d8c2973f8884848ea
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-ghc-typelits-knownnat/html/ghc-typelits-knownnat.haddock
haddock-html: /usr/share/doc/haskell-ghc-typelits-knownnat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-knownnat-0.6-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-typelits-knownnat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-typelits-knownnat
version: 0.6
id: ghc-typelits-knownnat-0.6-2l65EuMUsdqFInKH66lzYd
key: ghc-typelits-knownnat-0.6-2l65EuMUsdqFInKH66lzYd
license: BSD-2-Clause
copyright: Copyright © 2016     , University of Twente,
           2017-2018, QBayLogic B.V.,
           2017     , Google Inc.
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://clash-lang.org/
synopsis: Derive KnownNat constraints from other KnownNat constraints
description:
    A type checker plugin for GHC that can derive \"complex\" @KnownNat@
    constraints from other simple/variable @KnownNat@ constraints. i.e. without
    this plugin, you must have both a @KnownNat n@ and a @KnownNat (n+2)@
    constraint in the type signature of the following function:
    .
    @
    f :: forall n . (KnownNat n, KnownNat (n+2)) => Proxy n -> Integer
    f _ = natVal (Proxy :: Proxy n) + natVal (Proxy :: Proxy (n+2))
    @
    .
    Using the plugin you can omit the @KnownNat (n+2)@ constraint:
    .
    @
    f :: forall n . KnownNat n => Proxy n -> Integer
    f _ = natVal (Proxy :: Proxy n) + natVal (Proxy :: Proxy (n+2))
    @
    .
    The plugin can derive @KnownNat@ constraints for types consisting of:
    .
    * Type variables, when there is a corresponding @KnownNat@ constraint
    .
    * Type-level naturals
    .
    * Applications of the arithmetic expression: +,-,*,^
    .
    * Type functions, when there is either:
    .
    1. a matching given @KnownNat@ constraint; or
    .
    2. a corresponding @KnownNat\<N\>@ instance for the type function
    .
    To use the plugin, add the
    .
    @
    OPTIONS_GHC -fplugin GHC.TypeLits.KnownNat.Solver
    @
    .
    Pragma to the header of your file.
category: Type System
abi: 65a99784148690104913d2bc9039187e
exposed: True
exposed-modules:
    GHC.TypeLits.KnownNat GHC.TypeLits.KnownNat.Solver
hidden-modules: GHC.TypeLits.KnownNat.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/ghc-typelits-knownnat-0.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/ghc-typelits-knownnat-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ghc-typelits-knownnat-0.6
hs-libraries: HSghc-typelits-knownnat-0.6-2l65EuMUsdqFInKH66lzYd
depends:
    base-4.11.1.0 ghc-8.4.3
    ghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB
    ghc-typelits-natnormalise-0.6.2-EIVHJpQRDQbDkaHy66XoaR
    transformers-0.5.5.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-8.4.3=b85a78185b88bdae88410d8ef8f69684
             ghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB=ce7823a6fd180b4f7432a3604d6a13e8
             ghc-typelits-natnormalise-0.6.2-EIVHJpQRDQbDkaHy66XoaR=ed21f943764f1838268a3e51ae0a64b5
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-ghc-typelits-knownnat/html/ghc-typelits-knownnat.haddock
haddock-html: /usr/share/doc/haskell-ghc-typelits-knownnat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
